==> percona-xtradb-cluster_8.0.39-30.orig.tar.gz: Percona-XtraDB-Cluster-8.0.39-30/percona-xtradb-cluster-galera/cmake_install.cmake <==
# Install script for directory: /mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera

# Set the install prefix
if(NOT DEFINED CMAKE_INSTALL_PREFIX)
  set(CMAKE_INSTALL_PREFIX "/usr/local/mysql")
endif()
string(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
if(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  if(BUILD_TYPE)
    string(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  else()
    set(CMAKE_INSTALL_CONFIG_NAME "RelWithDebInfo")
  endif()
  message(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
endif()

# Set the component getting installed.
if(NOT CMAKE_INSTALL_COMPONENT)
  if(COMPONENT)
    message(STATUS "Install component: \"${COMPONENT}\"")
    set(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  else()
    set(CMAKE_INSTALL_COMPONENT)
  endif()
endif()

# Install shared libraries without execute permission?
if(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)
  set(CMAKE_INSTALL_SO_NO_EXE "0")
endif()

# Is this installation the result of a crosscompile?
if(NOT DEFINED CMAKE_CROSSCOMPILING)
  set(CMAKE_CROSSCOMPILING "FALSE")
endif()

if("x${CMAKE_INSTALL_COMPONENT}x" STREQUAL "xUnspecifiedx" OR NOT CMAKE_INSTALL_COMPONENT)
  file(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/doc" TYPE FILE FILES
    "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/AUTHORS"
    "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/COPYING"
    "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/README"
    )
endif()

if("x${CMAKE_INSTALL_COMPONENT}x" STREQUAL "xUnspecifiedx" OR NOT CMAKE_INSTALL_COMPONENT)
  file(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/doc" TYPE FILE RENAME "LICENSE.asio" FILES "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/asio/LICENSE_1_0.txt")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for each subdirectory.
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/cmake_install.cmake")
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/garb/cmake_install.cmake")
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcomm/cmake_install.cmake")
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcache/cmake_install.cmake")
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcs/cmake_install.cmake")
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/cmake_install.cmake")
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/scripts/packages/cmake_install.cmake")
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/wsrep/tests/cmake_install.cmake")

endif()

==> percona-xtradb-cluster_8.4.6-6.orig.tar.gz: Percona-XtraDB-Cluster-8.4.6-6/percona-xtradb-cluster-galera/cmake_install.cmake <==
# Install script for directory: /mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera

# Set the install prefix
if(NOT DEFINED CMAKE_INSTALL_PREFIX)
  set(CMAKE_INSTALL_PREFIX "/usr/local/mysql")
endif()
string(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
if(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  if(BUILD_TYPE)
    string(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  else()
    set(CMAKE_INSTALL_CONFIG_NAME "RelWithDebInfo")
  endif()
  message(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
endif()

# Set the component getting installed.
if(NOT CMAKE_INSTALL_COMPONENT)
  if(COMPONENT)
    message(STATUS "Install component: \"${COMPONENT}\"")
    set(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  else()
    set(CMAKE_INSTALL_COMPONENT)
  endif()
endif()

# Install shared libraries without execute permission?
if(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)
  set(CMAKE_INSTALL_SO_NO_EXE "0")
endif()

# Is this installation the result of a crosscompile?
if(NOT DEFINED CMAKE_CROSSCOMPILING)
  set(CMAKE_CROSSCOMPILING "FALSE")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for the subdirectory.
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/cmake_install.cmake")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for the subdirectory.
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/garb/cmake_install.cmake")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for the subdirectory.
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcomm/cmake_install.cmake")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for the subdirectory.
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcache/cmake_install.cmake")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for the subdirectory.
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcs/cmake_install.cmake")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for the subdirectory.
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/cmake_install.cmake")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for the subdirectory.
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/scripts/packages/cmake_install.cmake")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for the subdirectory.
  include("/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/wsrep/tests/cmake_install.cmake")
endif()

if("x${CMAKE_INSTALL_COMPONENT}x" STREQUAL "xUnspecifiedx" OR NOT CMAKE_INSTALL_COMPONENT)
  file(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/doc" TYPE FILE FILES
    "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/AUTHORS"
    "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/COPYING"
    "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/README"
    )
endif()

if("x${CMAKE_INSTALL_COMPONENT}x" STREQUAL "xUnspecifiedx" OR NOT CMAKE_INSTALL_COMPONENT)
  file(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/doc" TYPE FILE RENAME "LICENSE.asio" FILES "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/asio/LICENSE_1_0.txt")
endif()
